@@ -85,8 +85,8 @@ class InfoEndpointResponseModelBase(BaseModel):
     schema_version: str
     taktile_cli: str
     profiling: str
-    git_sha: str
-    git_ref: str
+    git_sha: t.Optional[str] = "unknown"
+    git_ref: t.Optional[str] = "unknown"
 
 
 class InfoEndpointResponseModelFlight(InfoEndpointResponseModelBase):
